Coverage for C:\src\imod-python\imod\typing\__init__.py: 100%

1"""

2 Module to define type aliases.

3"""

4

5 from typing import TypeAlias, Union

6

7 import numpy as np

8 import xarray as xr

9 import xugrid as xu

10

11 GridDataArray: TypeAlias = Union[xr.DataArray, xu.UgridDataArray]

12 GridDataset: TypeAlias = Union[xr.Dataset, xu.UgridDataset]

13 ScalarAsDataArray: TypeAlias = Union[xr.DataArray, xu.UgridDataArray]

14 ScalarAsDataset: TypeAlias = Union[xr.Dataset, xu.UgridDataset]

15 UnstructuredData: TypeAlias = Union[xu.UgridDataset, xu.UgridDataArray]

16 FloatArray: TypeAlias = np.ndarray

17 IntArray: TypeAlias = np.ndarray